===============================
Geezeo SDK
===============================

.. image:: https://img.shields.io/travis/Geezeo/sdk-python.svg
        :target: https://travis-ci.org/Geezeo/sdk-python

.. image:: https://img.shields.io/pypi/v/sdk-python.svg
        :target: https://pypi.python.org/pypi/sdk-python


Connect to the Geezeo API.

* Free software: ISC license
* Documentation: https://geezeo.readthedocs.org.

Features
--------

* TODO
